#!perl -T

use Test::More tests => 1;

use_ok( 'Wiki::Toolkit::Formatter::XHTMLMediaWiki' );

#diag( "Testing Wiki::Toolkit::Formatter::XHTMLMediaWiki $Wiki::Toolkit::Formatter::XHTMLMediaWiki::VERSION, Perl $], $^X" );
